import { Component, OnInit } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { Router } from '@angular/router';
import Swal from 'sweetalert2';
import { FormCreateQuizComponent } from '../form-quiz/form-create-quiz/form-create-quiz.component';

@Component({
    selector: 'app-home-page',
    templateUrl: './home-page.component.html',
    styleUrl: './home-page.component.css',
})
export class HomePageComponent implements OnInit {
    showQuickGame: boolean = false;
    showPlayQuiz: boolean = false;
    showMyQuiz: boolean = false;
    constructor(public router: Router, public dialog: MatDialog) {}
    ngOnInit(): void {}
    startParty() {
        Swal.fire({
            title: 'Join a Quiz',
            input: 'number',
            inputAttributes: {
                autocapitalize: 'off',
                placeholder: 'Quiz code',
            },
            showCloseButton: true,
            confirmButtonText: 'Go !',
            confirmButtonColor: '#7E3F97',
            showLoaderOnConfirm: true,
            preConfirm: async (login) => {
                try {
                    /* Requette a l'api pour recuperer le bon quizz */
                } catch (error) {
                    Swal.showValidationMessage(`Request failed: ${error}`);
                }
            },
            allowOutsideClick: () => !Swal.isLoading(),
        }).then((result) => {
            if (result.isConfirmed) {
                /* Redirection vers la page du quizz */
            }
        });
    }

    quickGame() {
        this.showQuickGame = true;
        this.showPlayQuiz = false;
        this.showMyQuiz = false;
    }

    playQuiz() {
        this.showQuickGame = false;
        this.showPlayQuiz = true;
        this.showMyQuiz = false;
    }

    myQuiz() {
        this.showQuickGame = false;
        this.showPlayQuiz = false;
        this.showMyQuiz = true;
    }

    async createParty(enterAnimationDuration: string, exitAnimationDuration: string) {
        this.dialog
            .open(FormCreateQuizComponent, {
                width: '50rem',
                enterAnimationDuration,
                exitAnimationDuration,
                panelClass: 'custom-dialog-overlay',
                hasBackdrop: false,
            })
            .afterClosed()
            .subscribe(() => {});
    }
}
